Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1513)

Unified Diff: Source/platform/Theme.h

Issue 1186523004: Rename adjustPaintInvalidationRect and related to addVisualOverflow (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/modules/accessibility/AXObject.cpp ('k') | Source/platform/mac/ThemeMac.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/platform/Theme.h
diff --git a/Source/platform/Theme.h b/Source/platform/Theme.h
index 0cd51dda4215e0b1c848d30981e7ef5ac8903bf7..407127329a982ef17959c6a3659dc1b8d3c614b0 100644
--- a/Source/platform/Theme.h
+++ b/Source/platform/Theme.h
@@ -96,11 +96,9 @@ public:
// Method for painting a control. The rect is in zoomed coordinates.
virtual void paint(ControlPart, ControlStates, GraphicsContext*, const IntRect& /*zoomedRect*/, float /*zoomFactor*/, ScrollableArea*) const { }
- // Some controls may spill out of their containers (e.g., the check on an OS X checkbox). When these controls repaint,
- // the theme needs to communicate this inflated rect to the engine so that it can invalidate the whole control.
- // The rect passed in is in zoomed coordinates, so the inflation should take that into account and make sure the inflation
- // amount is also scaled by the zoomFactor.
- virtual void inflateControlPaintRect(ControlPart, ControlStates, IntRect& /*zoomedRect*/, float /*zoomFactor*/) const { }
+ // Add visual overflow (e.g., the check on an OS X checkbox). The rect passed in is in zoomed coordinates so
+ // the inflation should take that into account and make sure the inflation amount is also scaled by the zoomFactor.
+ virtual void addVisualOverflow(ControlPart, ControlStates, float zoomFactor, IntRect& borderBox) const { }
private:
mutable Color m_activeSelectionColor;
« no previous file with comments | « Source/modules/accessibility/AXObject.cpp ('k') | Source/platform/mac/ThemeMac.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698